@@ -108,7 +108,7 @@
 Return (LEFT TOP WIDTH HEIGHT) or nil."
   (let* ((rs (max start (window-start window)))
          (re (min end (window-end window t)))
-         (edges (window-inside-pixel-edges window))
+         (edges (window-inside-absolute-pixel-edges window))
          minx miny maxx maxy)
     (when (< rs re)
       (save-excursion
@@ -283,6 +283,7 @@ Optional PARENT-BUFFER and PARENT-FRAME default to the current
 buffer and frame.
 PARAMETERS is an alist of frame parameters overriding the
 defaults."
+  ;; Code is adapted from corfu and posframe
   (let* ((window-min-height 1)
          (window-min-width 1)
          (inhibit-redisplay t)
@@ -356,7 +357,6 @@ defaults."
     ;; top of the Corfu child frame.
     (when (and (bound-and-true-p exwm--connection) (frame-parent frame))
       (set-frame-parameter frame 'parent-frame nil))
-
     frame))
 
 (defun buframe-update (frame-or-name)
